@@ -10,7 +10,7 @@ sub parse {
     my $self = shift;
     my $text = shift;
     $text =~ /$pattern/ or return;
-    my $alt = $self->sanitize($1);
+    my $alt = $self->escape_attr($1);
     my $tex = $1;
     $tex =~ s/\\([\[\]])/$1/g;
     $tex =~ s/\s/~/g;
